Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FakeStats ¶
type FakeStats struct {
}
FakeStats implements Stats interface wherein for instead of sending the stats backend, it just logs the messages.
type Stats ¶
type Stats interface {
// IncCount captures the continuous stats (identified by name)
// and delivers it to statsd backend
IncCount(name string, tags ...string)
// ServiceCheck captures the status of a service when a change in the
// service status was notified
ServiceCheck(name, mesg string, status int, timestamp time.Time, tags ...string)
// Event contains details of an activity that was captured and
// notifies it to stats backend
Event(title, mesg, aggKey, typ string, timestamp time.Time, tags ...string)
}
Stats allows sending increment, service check and event message to statsd backend
Click to show internal directories.
Click to hide internal directories.